Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(233)

Unified Diff: include/gpu/GrBackendProcessorFactory.h

Issue 659803005: Last round of effect->processor (for now) (Closed) Base URL: https://skia.googlesource.com/skia.git@factory
Patch Set: fixed Created 6 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | include/gpu/GrCoordTransform.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/gpu/GrBackendProcessorFactory.h
diff --git a/include/gpu/GrBackendProcessorFactory.h b/include/gpu/GrBackendProcessorFactory.h
index 6544b307a71159b78f01f281e82f21ee90cfa8e3..3e4f13314756734cfb5c7957a1db0f969e9da2e9 100644
--- a/include/gpu/GrBackendProcessorFactory.h
+++ b/include/gpu/GrBackendProcessorFactory.h
@@ -111,22 +111,22 @@ public:
* processor's key. This allows keys generated by getGLProcessorKey() to only be unique within a
* GrProcessor subclass and not necessarily across subclasses.
*/
- uint32_t effectClassID() const { return fEffectClassID; }
+ uint32_t classID() const { return fProcessorClassID; }
protected:
- GrBackendProcessorFactory() : fEffectClassID(GenID()) {}
+ GrBackendProcessorFactory() : fProcessorClassID(GenClassID()) {}
virtual ~GrBackendProcessorFactory() {}
private:
enum {
- kIllegalEffectClassID = 0,
+ kIllegalProcessorClassID = 0,
};
- static uint32_t GenID() {
- // fCurrEffectClassID has been initialized to kIllegalEffectClassID. The
+ static uint32_t GenClassID() {
+ // fCurrProcessorClassID has been initialized to kIllegalProcessorClassID. The
// atomic inc returns the old value not the incremented value. So we add
// 1 to the returned value.
- uint32_t id = static_cast<uint32_t>(sk_atomic_inc(&fCurrEffectClassID)) + 1;
+ uint32_t id = static_cast<uint32_t>(sk_atomic_inc(&fCurrProcessorClassID)) + 1;
if (!id) {
SkFAIL("This should never wrap as it should only be called once for each GrProcessor "
"subclass.");
@@ -134,8 +134,8 @@ private:
return id;
}
- const uint32_t fEffectClassID;
- static int32_t fCurrEffectClassID;
+ const uint32_t fProcessorClassID;
+ static int32_t fCurrProcessorClassID;
};
class GrFragmentProcessor;
« no previous file with comments | « no previous file | include/gpu/GrCoordTransform.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698